localStackDatabaseUsername top-level constant
Username of the Postgres superuser of the local stack.
Implementation
@visibleForTesting
const localStackDatabaseUsername = 'postgres';
Username of the Postgres superuser of the local stack.
@visibleForTesting
const localStackDatabaseUsername = 'postgres';